@@ -4,7 +4,7 @@ from clarifai_grpc.grpc.api.status import status_code_pb2
 
 
 def inputs_generator(stub: V2Stub, metadata: tuple, user_id: str, app_id: str,
-                     page_size: int = 16):
+                     page_size: int = 16, only_successful_inputs: bool = True):
   """
   Lists all the inputs in the given userAppID user_id, app_id app. This uses the more efficient
   streaming input listing technique.
@@ -15,6 +15,7 @@ def inputs_generator(stub: V2Stub, metadata: tuple, user_id: str, app_id: str,
     user_id: the user to list from.
     app_id: the app in the user_id account to list from.
     page_size: the pagination size to use while iterating.
+    only_successful_inputs: only accept inputs with non-failure statuses.
   """
   userDataObject = resources_pb2.UserAppIDSet(user_id=user_id, app_id=app_id)
 
@@ -23,7 +24,7 @@ def inputs_generator(stub: V2Stub, metadata: tuple, user_id: str, app_id: str,
       status_code_pb2.INPUT_DOWNLOAD_IN_PROGRESS
   }
 
-  response_success_status = {status_code_pb2.SUCCESS}
+  response_success_status = {status_code_pb2.SUCCESS, status_code_pb2.MIXED_STATUS}
 
   last_id = ''
 
@@ -39,4 +40,8 @@ def inputs_generator(stub: V2Stub, metadata: tuple, user_id: str, app_id: str,
     else:
       for inp in response.inputs:
         last_id = inp.id
-        yield inp
+        if only_successful_inputs:
+          if inp.status.code in input_success_status:
+            yield inp
+        else:
+          yield inp
